<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;
use Illuminate\View\View;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     */
    public function create()
    {
        return redirect()->route('signup');
    }

    /**
     * Handle an incoming registration request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'username' => ['required','string','max:255','unique:'.User::class],
            'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:'.User::class],
            'phone' => ['required', 'string'],
            'profile_img' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // 2MB max
            'gender' => 'required|in:male,female,other',
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
        ]);

        $profileImagePath = null;
    if ($request->hasFile('profile_img')) {
        $file = $request->file('profile_img');
        $profileImagePath = $file->store('profile_images', 'public'); // Save to storage/app/public/profile_images
    }

        $user = User::create([
            'name' => $request->name,
            'username' => $request->username,
            'email' => $request->email,
            'phone' => $request->phone,
            'bio' => $request->bio,
            'profile_img' => $profileImagePath, // Save the file path
            'gender' => $request->gender,
            'date_of_birth' => $request->date_of_birth,
            'password' => Hash::make($request->password),
        ]);

        event(new Registered($user));

        Auth::login($user);

        return redirect(route('shorts', absolute: false));
    }
}
