<?php

namespace App\Http\Controllers;

use Illuminate\View\View;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use App\Http\Requests\ProfileUpdateRequest;

class ProfileController extends Controller
{
    /**
     * Display the user's profile form.
     */

    public function profile()
    {
        $user = auth()->user();
        $reels = $user->reels()->with('user')->get();
        return view('front.profile', compact('reels','user'));
    }
 
    public function edit(Request $request): View
    {
        $user = auth()->user();
        return view('profile.edit', compact('user'));
    }

    /**
     * Update the user's profile information.
     */
    public function update(ProfileUpdateRequest $request): RedirectResponse
    {
        $request->user()->fill($request->validated());

        if ($request->user()->isDirty('email')) {
            $request->user()->email_verified_at = null;
        }
        
        $user = Auth::user();

        // $request->validate([
        //     'name' => 'required|string|max:255',
        //     'bio' => 'nullable|string',
        //     'profile_img' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        // ]);

        $user->name = $request->name;
        $user->bio = $request->bio;

        if ($request->hasFile('profile_img')) {
            // Delete the old profile image if it exists
            if ($user->profile_img) {
                // Construct the full path to the old image
                $oldImagePath = public_path('assets/profile_images/' . basename($user->profile_img));
                if (file_exists($oldImagePath)) {
                    unlink($oldImagePath); // Delete the old image
                }
            }
        
            // Get the file from the request
            $file = $request->file('profile_img');
        
            // Generate a unique file name
            $fileName = time() . '_' . $file->getClientOriginalName();
        
            // Define the storage path
            $finalPath = 'profile_images/' . $fileName;
        
            // Move the file to the public/assets/profile_images directory
            $file->move(public_path('assets/profile_images'), $fileName);
        
            // Save the relative path to the database
            $user->profile_img = $finalPath;
        }

        $user->save();

        return Redirect::route('profile.edit')->with(['success' => true, 'message' => 'profile-updated']);
    }

    /**
     * Delete the user's account.
     */
    public function destroy(Request $request): RedirectResponse
    {
        $request->validateWithBag('userDeletion', [
            'password' => ['required', 'current_password'],
        ]);

        $user = $request->user();

        Auth::logout();

        $user->delete();

        $request->session()->invalidate();
        $request->session()->regenerateToken();

        return Redirect::to('/');
    }

    public function logout(Request $request)
    {
        Auth::logout();
        $request->session()->invalidate();
        $request->session()->regenerateToken();
        return redirect('/login');
    }
}
