<?php

namespace App\Http\Controllers;

use FFMpeg\FFMpeg;
use Pusher\Pusher;
use App\Models\Like;
use App\Models\Reel;
use App\Models\Report;
use App\Models\Notification;
use Illuminate\Http\Request;
use FFMpeg\Coordinate\TimeCode;
use App\Events\LikeNotification;
use Illuminate\Support\Facades\Auth;
use GrahamCampbell\ResultType\Success;
use Illuminate\Support\Facades\Storage;
use App\Notifications\PostLikedNotification;

class ReelController extends Controller
{
    public function index()
    {
        $reels = Reel::with('user')->latest()->paginate(10); // Fetch latest reels
        return view('front.reels.index', compact('reels'));
    }

    // public function store(Request $request)
    // {
    //     $request->validate([
    //         'video' => 'required|mimes:mp4,mov,avi|max:102400', // 100MB max
    //         'caption' => 'nullable|string|max:255',
    //         'hashtags' => 'nullable|string',
    //     ]);

    //     $videoPath = $request->file('video')->store('videos', 'public');

    //     // Generate Thumbnail using FFmpeg or Intervention/Image
    //     $thumbnailPath = 'thumbnails/' . basename($videoPath) . '.jpg';

    //     Reel::create([
    //         'user_id' => Auth::id(),
    //         'video_path' => $videoPath,
    //         'thumbnail_path' => $thumbnailPath,
    //         'caption' => $request->caption,
    //         'hashtags' => $request->hashtags,
    //     ]);

    //     return redirect()->route('shorts')->with('success', 'Reel uploaded successfully!');
    // }

    // public function store(Request $request)
    // {
    //     // Get info from the request
    //     $fileName  = $request->input('fileName'); 
    //     $startByte = $request->input('startByte');
    //     $chunk     = $request->file('video');
        
    //     // The *entire* file’s size, sent from the front end
    //     $totalSize = $request->input('fileSize'); 
        
    //     // Build an absolute path for the temp file in 'public/videos'
    //     // e.g. "C:/.../storage/app/public/videos/temp_originalfilename.mp4"
    //     $tempPath = Storage::disk('public')->path("videos/temp_{$fileName}");

    //     // Append this chunk’s data to the temp file
    //     file_put_contents($tempPath, file_get_contents($chunk), FILE_APPEND);

    //     // Check if we now have the full file
    //     // Compare the *temp file size* to the *total size* from the client
    //     if (filesize($tempPath) >= $totalSize) {
    //         // Construct a final path, e.g. "videos/1680000000_original.mp4"
    //         $finalPath = 'videos/' . time() . '_' . $fileName;

    //         // Move the temp file to the final location
    //         Storage::disk('public')->move("videos/temp_{$fileName}", $finalPath);

    //         // (Optional) store in DB. Adjust 'Reel' to your own model/table if needed
    //         Reel::create([
    //             'user_id'    => Auth::id(),
    //             'video_path' => $finalPath,  // saving only the relative path
    //             'caption'    => $request->input('caption'),
    //             'hashtags'   => $request->input('hashtags'),
    //             'privacy' => $request->input('privacy'),
    //         ]);

    //         // If you need the size of the final file:
    //         $absoluteFinalPath = Storage::disk('public')->path($finalPath);
    //         $finalSize         = filesize($absoluteFinalPath);

    //         return response()->json([
    //             'success'       => true,
    //             'uploadedBytes' => $finalSize,
    //         ]);
    //     }

    //     // If not fully uploaded, return how many bytes we have so far
    //     $uploadedSoFar = filesize($tempPath);
    //     return response()->json([
    //         'success'       => true,
    //         'uploadedBytes' => $uploadedSoFar,
    //     ]);
    // }

    public function store(Request $request)
    {
        $fileName  = $request->input('fileName'); 
        $startByte = $request->input('startByte');
        $chunk     = $request->file('video');
        
        // The *entire* file’s size, sent from the front end
        $totalSize = $request->input('fileSize'); 
        
        // Build an absolute path for the temp file in 'public/videos'
        // e.g. "C:/.../public/videos/temp_originalfilename.mp4"
        $tempPath = public_path("videos/temp_{$fileName}");

        // Ensure the 'videos' directory exists in the public folder
        if (!file_exists(public_path('videos'))) {
            mkdir(public_path('videos'), 0777, true);
        }

        // Append this chunk’s data to the temp file
        file_put_contents($tempPath, file_get_contents($chunk), FILE_APPEND);

        // Check if we now have the full file
        // Compare the *temp file size* to the *total size* from the client
        if (filesize($tempPath) >= $totalSize) {
            // Construct a final path, e.g. "videos/1680000000_original.mp4"
            $finalPath = 'videos/' . time() . '_' . $fileName;

            // Move the temp file to the final location in the public folder
            rename($tempPath, public_path($finalPath));

            // (Optional) store in DB. Adjust 'Reel' to your own model/table if needed
            Reel::create([
                'user_id'    => Auth::id(),
                'video_path' => $finalPath,  // saving only the relative path
                'caption'    => $request->input('caption'),
                'hashtags'   => $request->input('hashtags'),
                'privacy' => $request->input('privacy'),
            ]);

            // If you need the size of the final file:
            $absoluteFinalPath = public_path('assets/'. $finalPath);
            $finalSize         = filesize($absoluteFinalPath);
            return response()->json([
                'success'       => true,
                'uploadedBytes' => $finalSize,
            ]);
        }
    }

    public function showReel(Reel $reel)
    {
        return view('front.reels.detail', compact('reel'));
    }

    public function editReel(Request $request, Reel $reel)
    {
        $request->validate([
            'caption' => 'nullable|string|max:255', // Adjust max length as needed
            'hashtags' => 'nullable|string|max:255', // Adjust max length as needed
            'privacy' => 'required|in:public,private,friends', // Adjust privacy options as needed
        ]);

        // Update the reel
        $reel->update([
            'caption' => $request->input('caption'),
            'hashtags' => $request->input('hashtags'),
            'privacy' => $request->input('privacy'),
        ]);

        // Return a response (e.g., success message)
        return response()->json(['success' => true]);
    }

    public function deleteReel(Reel $reel)
    {
        $reel->delete();
        return response()->json(['success' => true]);
    }

    public function like($id)
    {
        $reel = Reel::findOrFail($id);
        $like = Like::where('user_id', Auth::id())->where('reel_id', $id)->first();

        if ($like) {
            $like->delete(); // Unlike if already liked
            $liked = null;
        } else {
            $like = Like::create(['user_id' => Auth::id(), 'reel_id' => $id]);
            $liked = 'liked';
            $reel->user->notify(new PostLikedNotification($reel));

            
            // $notification = Notification::create([
            //     'notifiable_id' => $reel->id,
            //     'notifiable_type' => Reel::class,
            //     'user_id' => $reel->user_id,
            //     'type' => 'like',
            //     'data' => [
            //         'message' => auth()->user()->name . ' liked Your post.',
            //         'user_img' => auth()->user()->profile_img,
            //     ],
            // ]);

        }

        return response()->json(['likes' => $reel->likes()->count(), 'success' => true, 'liked' => $liked]);
    }

    public function reportReel($reelId)
    {
        $reel = Reel::find($reelId); // Replace 1 with the reel ID
        $report = new Report();
        $report->reporter_id = Auth::id();
        $report->reason = 'Inappropriate content.';
        $report->reportable()->associate($reel);
        $report->save();

        return redirect()->route('shorts')->with('message', 'Reel Reported Successfully!');
    }


}
